---
obsidianUIMode: preview
---

This section presents a number of tricks and tips that can help you more easily prepare and run monsters during your games. We call them "lazy tricks" not because they're about cheating or doing less work overall, but because they're meant to let you quickly accomplish things when your game is in progress and you don't have a lot of extra time.

## Quick Monster Statistics

"Building a Quick Monster" provides great guidelines for creating a foe for your game in just a few minutes. But you can come up with an even quicker set of monster statistics using the following steps.

First, choose a challenge rating for your monster, based on their perceived power in the encounter. When needed, compare your monster to existing monsters to find a suitable challenge rating. Then use the following guidelines to craft their baseline statistics:

* Armor Class = 12 + 1/2 CR
* Hit points = (15 × CR) + 15
* Proficient saving throws and skills = 4 + 1/2 CR
* Nonproficient saving throws and abilities = −2 to +2, based on the monster's story
* Attack bonus = 4 + 1/2 CR
* DC for saving throws = 12 + 1/2 CR
* Total damage per round = (7 × CR) + 5

Start your monster out with one attack, then add one additional attack at CR 2, CR 7, CR 11, and CR 15. Split the total damage noted above across all attacks.

With a solid set of combat statistics at hand, you can then use narrative descriptions to make your monster unique, interesting, and evocative.

## Ten Useful Monster Features

Give any custom monster impactful features and attacks that make sense for their place in the game. When a monster feature deals damage, choose a damage type appropriate to the creature's physiology, theme, or story. A creature channeling magical power might deal acid, cold, fire, lightning, force, poison, psychic, necrotic, radiant, or thunder damage. A creature making use of spines, spikes, or projectiles might deal bludgeoning, piercing, or slashing damage.

***Damaging Blast.*** This creature has one or more single-target ranged attacks using the attack bonus and damage calculated above, and which deal damage of an appropriate type.

***Damage Reflection.*** Whenever a creature within 5 feet of this creature hits them with a melee attack, the attacker takes damage in return of a type appropriate to the creature. The damage dealt is equal to half the damage of one of this creature's attacks. If you give a creature this feature, give them one less attack than normal.

***Misty Step.*** As a bonus action, this creature can teleport up to 30 feet to an unoccupied space they can see.

***Knockdown.*** When this creature hits a target with a melee attack, the target must succeed on a Strength saving throw or be knocked prone.

***Restraining Grab.*** When this creature hits a target with a melee attack, the target is grappled (escape DC based on this creature's Strength or Dexterity modifier). While grappled, the target is restrained.

***Damaging Burst.*** As an action, this creature can create a burst of energy, magic, spines, or some other effect in a 10-foot-radius sphere, either around themself or at a point within 120 feet. Each creature in that area must make a Dexterity, Constitution, or Wisdom saving throw (your choice, based on the type of burst). On a failure, a target takes damage of an appropriate type equal to half this creature's total damage per round. On a success, a target takes half as much damage.

***Cunning Action***. On each of their turns, this creature can use a bonus action to take the Dash, Disengage, or Hide action.

***Damaging Aura.*** Each creature who starts their turn within 10 feet of this creature takes damage of a type appropriate to the creature. The damage dealt is equal to half the damage of one of this creature's attacks. If you give a creature this feature, give them one less attack than normal.

***Energy Weapons.*** The creature's weapon attacks deal extra damage of an appropriate type. You can add this damage on top of the creature's regular damage output to give them a combat boost, or you can replace some of the creature's normal weapon damage with this energy damage.

***Damage Transference.*** When this creature takes damage, they can transfer half or all of that damage (your choice) to a willing creature within 30 or 60 feet of them. This feature is particularly good for boss monsters.

## Using Averages

By default, 5e monster stat blocks calculate the average damage for any attack's dice expression, as with "13 (2d8 + 4) bludgeoning damage" for an ogre's Greatclub attack. Using average damage for a monster's attacks is one of the best ways to speed up combat.

Sometimes, though, you need to roll damage for effects that aren't in a stat block. When you do, you can use the following table to quickly look up the average value of various dice equations. Simply find the number of dice in the leftmost column, then go across to the appropriate die type. As can be seen in the table, you can add up averages to get an average value for higher numbers of dice—for example, adding the average of 2d10 and 6d10 to get the average of 8d10. You can use this approach to find the average for rolling more than twelve dice, so that if you need an average for 24d10, you can simply look at the 12d10 average and double it.

| # of dice | d4 | d6 | d8 | d10 | d12 |
| --------- | -- | -- | -- | --- | --- |
| 1         | 2  | 3  | 4  | 5   | 6   |
| 2         | 5  | 7  | 9  | 11  | 13  |
| 3         | 7  | 10 | 13 | 16  | 19  |
| 4         | 10 | 14 | 18 | 22  | 26  |
| 5         | 12 | 17 | 22 | 27  | 32  |
| 6         | 15 | 21 | 27 | 33  | 39  |
| 7         | 17 | 24 | 31 | 38  | 45  |
| 8         | 20 | 28 | 36 | 44  | 52  |
| 9         | 22 | 31 | 40 | 49  | 58  |
| 10        | 25 | 35 | 45 | 55  | 65  |
| 11        | 27 | 38 | 49 | 60  | 71  |
| 12        | 30 | 42 | 54 | 66  | 78  |

You can also compute averages for dice expressions with simple equations you can keep in your head. The average of two dice is the maximum value of one of those dice + 1, so that the average of 2d12 is 13. Then double that number for multiples of two, so that the average of 2d8 is 9, the average of 4d8 is 18, and so forth. Likewise, the average of a single die is half the size of the die, so add that number to a two-dice average to get odd numbers. For example, the average of 4d6 is 14, so the average of 5d6 is 17. (The average of one die is actually half the size of the die plus 0.5, which is why the average of two dice is the maximum value of the die +1.)

## Other Lazy Monster Tricks

Once you're in the middle of an encounter, you can make use of a number of other quick tricks to make running monsters easier, with more flexibility and greater speed. Try any of the following options at your table, and make use of any trick that helps your game:

* Use fixed initiative for monsters equal to 10 + each monster's Dexterity bonus. Even faster? Just have all monsters act on initiative count 12.
* Reduce hit points on the fly to allow monsters to drop or surrender more quickly, or increase a monster's number of attacks or damage if the characters are having too easy a time.
* Have foes flee or surrender when it makes sense to move the game forward.
* Have constructs and undead be destroyed when the creature controlling them dies.
* Run multiple waves of monsters for big battles.

Include creatures designed to eat "save or suck" attacks such as *banishment* or *polymorph*.
